@@ -8,10 +8,10 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     Revised BSD License for more details.
 
-    Copyright 2004-2017 iDB Support - http://idb.berlios.de/
-    Copyright 2004-2017 Game Maker 2k - http://gamemaker2k.org/
+    Copyright 2004-2019 iDB Support - https://idb.osdn.jp/support/category.php?act=view&id=1
+    Copyright 2004-2019 Game Maker 2k - https://idb.osdn.jp/support/category.php?act=view&id=2
 
-    $FileInfo: function.php - Last Update: 06/23/2019 SVN 898 - Author: cooldude2k $
+    $FileInfo: function.php - Last Update: 4/8/2022 SVN 947 - Author: cooldude2k $
 */
 $File3Name = basename($_SERVER['SCRIPT_NAME']);
 if ($File3Name=="function.php"||$File3Name=="/function.php") {
@@ -78,8 +78,11 @@ if($Settings['fixredirectdir']!=null) {
 		$rbasedir = $Settings['fixredirectdir']; }
 $BaseURL = $basedir;
 // Get our Host Name and Referer URL's Host Name
-if(!isset($_SERVER['HTTP_REFERER'])) { $_SERVER['HTTP_REFERER'] = null; }
-$REFERERurl = parse_url($_SERVER['HTTP_REFERER']);
+if(!isset($_SERVER['HTTP_REFERER'])) {
+ $REFERERurl = null;
+ $_SERVER['HTTP_REFERER'] = null; }
+if(isset($_SERVER['HTTP_REFERER'])) {
+ $REFERERurl = parse_url($_SERVER['HTTP_REFERER']); }
 if(!isset($REFERERurl['host'])) { $REFERERurl['host'] = null; }
 $URL['REFERER'] = $REFERERurl['host'];
 $URL['HOST'] = $basecheck['host'];
@@ -419,7 +422,7 @@ if(!isset($_GET['id'])) { $_GET['id'] = null; }
 if(!isset($_GET['debug'])) { $_GET['debug'] = "false"; }
 if(!isset($_GET['post'])) { $_GET['post'] = null; }
 if(!isset($_POST['License'])) { $_POST['License'] = null; } }
-if($_SERVER['PATH_INFO']==null) {
+if(isset($_SERVER['PATH_INFO']) && $_SERVER['PATH_INFO']==null) {
 	if(getenv('PATH_INFO')!=null&&getenv('PATH_INFO')!="1") {
 $_SERVER['PATH_INFO'] = getenv('PATH_INFO'); }
 if(getenv('PATH_INFO')==null) {
